Class: VagrantPlugins::Azure::Provider

Inherits:
Object
  • Object
show all
Defined in:
lib/vagrant-azure/provider.rb

Instance Method Summary collapse

Constructor Details

#initialize(machine) ⇒ Provider

Returns a new instance of Provider.



11
12
13
14
15
16
17
18
19
20
21
# File 'lib/vagrant-azure/provider.rb', line 11

def initialize(machine)
  @machine = machine

  # Load the driver
  machine_id_changed

  # turn off nfs functionality by default, so the machine will fall back to rsync by default
  @machine.config.nfs.functional = false
  @machine.config.winrm.password = @machine.provider_config.admin_password
  @machine.config.winrm.username = @machine.provider_config.admin_username
end

Instance Method Details

#action(name) ⇒ Object



23
24
25
26
27
28
29
30
# File 'lib/vagrant-azure/provider.rb', line 23

def action(name)
  # Attempt to get the action method from the Action class if it
  # exists, otherwise return nil to show that we don't support the
  # given action.
  action_method = "action_#{name}"
  return Action.send(action_method) if Action.respond_to?(action_method)
  nil
end

#ssh_infoObject



32
33
34
35
36
37
38
# File 'lib/vagrant-azure/provider.rb', line 32

def ssh_info
  # Run a custom action called "read_ssh_info" which does what it
  # says and puts the resulting SSH info into the `:machine_ssh_info`
  # key in the environment.
  env = @machine.action('read_ssh_info')
  env[:machine_ssh_info]
end

#stateObject



45
46
47
48
49
50
51
52
53
54
55
56
57
# File 'lib/vagrant-azure/provider.rb', line 45

def state
  # Run a custom action we define called "read_state" which does what it
  # says. It puts the state in the `:machine_state_id` key in the env
  env = @machine.action('read_state')
  state_id = env[:machine_state_id]

  # Get the short and long description
  short = I18n.t("vagrant_azure.states.short_#{state_id}")
  long  = I18n.t("vagrant_azure.states.long_#{state_id}")

  # Return the MachineState object
  Vagrant::MachineState.new(state_id, short, long)
end

#to_sObject



59
60
61
62
# File 'lib/vagrant-azure/provider.rb', line 59

def to_s
  id = @machine.id.nil? ? 'new' : @machine.id
  "Azure (#{id})"
end

#winrm_infoObject



40
41
42
43
# File 'lib/vagrant-azure/provider.rb', line 40

def winrm_info
  env = @machine.action('read_winrm_info')
  env[:machine_winrm_info]
end